# matchescu-base
Common abstract data types (`adt` package) and utilities
(`common` package) for the **matchescu** entity resolution
comparison framework.

## Set up dev environment

1. (_optional_) install pyenv
2. install Python 3.11
3. install [Poetry](https://python-poetry.org)
4. clone this repository
5. run a couple of shell commands
```shell
$ cd <REPO_ROOT>
$ poetry install
```

## Run tests

```shell
$ poetry run pytest
```

## Activate virtual environment

```shell
$ poetry shell
```
-or-
```shell
$ source .venv/bin/activate
```
